@@ -31,10 +31,27 @@ def y_colorize_directory (path, variation):
 if os.path.exists("usr"):
     os.system("rm -rf usr/")
 
+start_dir = os.getcwd()
+
 os.system("mkdir -p usr/share/themes")
 
+# Mint-X ##################################################################
+
+# First build the Gtk4 css
+os.chdir("src/Mint-X/theme/Mint-X/gtk-4.0/")
+os.system("sassc ./sass/gtk.scss gtk.css")
+os.system("sassc ./sass/gtk-dark.scss gtk-dark.css")
+os.chdir(start_dir)
+
+# Then the Gtk3 css
+os.chdir("src/Mint-X/theme/Mint-X/gtk-3.0/")
+os.system("sassc ./sass/gtk.scss gtk.css")
+os.system("sassc ./sass/gtk-dark.scss gtk-dark.css")
+os.chdir(start_dir)
+
 os.system("cp -R src/Mint-X/theme/* usr/share/themes/")
 
+# Now do the other themes and color variations
 for color in os.listdir("src/Mint-X/variations"):
     path = os.path.join("src/Mint-X/variations", color)
     if os.path.isdir(path):
@@ -50,11 +67,27 @@ for color in os.listdir("src/Mint-X/variations"):
         # Accent color
         gtkrc = os.path.join(theme, "gtk-2.0", "gtkrc")
         settings_ini = os.path.join(theme, "gtk-3.0", "settings.ini")
-        gtk_main_css = os.path.join(theme, "gtk-3.0", "gtk-main.css")
-        for file in [gtkrc, settings_ini, gtk_main_css]:
+        gtk3_colors = os.path.join(theme, "gtk-3.0", "sass", "_colors.scss")
+        gtk4_colors = os.path.join(theme, "gtk-4.0", "sass", "_colors.scss")
+        for file in [gtkrc, settings_ini, gtk3_colors, gtk4_colors]:
             for accent in X_HEX_ACCENTS:
                 os.system("sed -i s'/%(accent)s/%(color_accent)s/' %(file)s" % {'accent': accent, 'color_accent': x_hex_colors[color], 'file': file})
 
+        # Build sass
+        sass_dir = os.path.join(theme, "gtk-4.0")
+        os.chdir(sass_dir)
+        os.system("sassc ./sass/gtk.scss gtk.css")
+        os.system("sassc ./sass/gtk-dark.scss gtk-dark.css")
+        os.system("rm -rf sass parse-sass.sh")
+        os.chdir(start_dir)
+
+        sass_dir = os.path.join(theme, "gtk-3.0")
+        os.chdir(sass_dir)
+        os.system("sassc ./sass/gtk.scss gtk.css")
+        os.system("sassc ./sass/gtk-dark.scss gtk-dark.css")
+        os.system("rm -rf sass parse-sass.sh")
+        os.chdir(start_dir)
+
         # Cinnamon theme name
         file = os.path.join(theme, "cinnamon", "theme.json")
         if os.path.exists(file):
@@ -68,6 +101,11 @@ for color in os.listdir("src/Mint-X/variations"):
             for accent in X_RGB_ACCENTS:
                 os.system("sed -i s'/%(accent)s/%(color_accent)s/' %(file)s" % {'accent': accent, 'color_accent': x_rgb_colors[color], 'file': file})
 
+os.system("rm -rf usr/share/themes/Mint-X/gtk-3.0/sass usr/share/themes/Mint-X/gtk-3.0/parse-sass.sh")
+os.system("rm -rf usr/share/themes/Mint-X/gtk-4.0/sass usr/share/themes/Mint-X/gtk-4.0/parse-sass.sh")
+
+# Mint-Y #################################################################
+
 curdir = os.getcwd()
 
 os.chdir("src/Mint-Y")
@@ -94,6 +132,21 @@ for color in y_hex_colors1.keys():
             for key in ["IconTheme"]:
                 change_value(key, "%s-%s" % (original_name, color), theme_index)
 
+            # Regenerate GTK4 sass
+            os.system("cp -R src/Mint-Y/gtk-4.0/sass %s/gtk-4.0/" % theme)
+            y_colorize_directory("%s/gtk-4.0/sass" % theme, color)
+            os.chdir("%s/gtk-4.0" % theme)
+
+            if (variant == "-Dark"):
+                os.system("cp sass/gtk-dark.scss sass/gtk.scss")
+                os.system("sassc ./sass/gtk.scss gtk.css")
+            else:
+                os.system("sassc ./sass/gtk-dark.scss gtk-dark.css")
+                os.system("sassc ./sass/gtk.scss gtk.css")
+
+            os.system("rm -rf sass .sass-cache")
+            os.chdir(curdir)
+
             # Regenerate GTK3 sass
             os.system("cp -R src/Mint-Y/gtk-3.0/sass %s/gtk-3.0/" % theme)
             y_colorize_directory("%s/gtk-3.0/sass" % theme, color)
@@ -150,6 +203,7 @@ for color in y_hex_colors1.keys():
                     y_colorize_directory(directory, color)
 
             # Assets
+            os.system("rm -rf %s/gtk-4.0/assets" % theme)
             os.system("rm -rf %s/gtk-3.0/assets" % theme)
             os.system("rm -rf %s/gtk-2.0/assets" % theme)
             if variant == "-Dark":
@@ -159,6 +213,7 @@ for color in y_hex_colors1.keys():
                 os.system("cp -R %s/gtk-2.0/assets %s/gtk-2.0/assets" % (path, theme))
                 os.system("cp -R %s/xfwm4/*.png %s/xfwm4/" % (path, theme))
             os.system("cp -R %s/gtk-3.0/assets %s/gtk-3.0/assets" % (path, theme))
+            os.system("cp -R %s/gtk-4.0/assets %s/gtk-4.0/assets" % (path, theme))
 
 
 # Files
